@@ -28,6 +28,7 @@ register_s3_method <- function(pkg, generic, class, fun = NULL) { # nocov start
   )
 }
 
+tidyr_at_least_1.0.0 <- NULL
 
 .onLoad <- function(libname, pkgname) {
 
@@ -41,6 +42,7 @@ register_s3_method <- function(pkg, generic, class, fun = NULL) { # nocov start
     register_s3_method("tidyr", "nest",   "tbl_time")
     register_s3_method("tidyr", "unnest", "tbl_time")
     register_s3_method("tidyr", "unnest", "tbl_df")
+    tidyr_at_least_1.0.0 <<- utils::packageVersion("tidyr") >= "1.0.0"
   }
 
   invisible()
