@@ -14,7 +14,7 @@ test_tbl_time_g <- as_tbl_time(FANG, date) %>%
 
 test_that("Converting to more granular throws error", {
   expect_error(as_period(test_tbl_time, "hourly"),
-               regexp = "Only year, quarter, month, week, and day periods are allowed for an index of class Date.")
+               regexp = "Only year, quarter, month, week, and day periods are allowed for an index of class Date")
 })
 
 test_that("Can convert to monthly", {
